Index: src/wp-admin/privacy.php
===================================================================
--- src/wp-admin/privacy.php	(revision 42819)
+++ src/wp-admin/privacy.php	(working copy)
@@ -60,7 +60,7 @@
 	}
 }
 
 // If a privacy policy page ID is available, make sure the page actually exists. If not, display a warning
 $privacy_policy_page_exists = false;
 $privacy_policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
 
@@ -71,7 +71,7 @@
 				'page_for_privacy_policy',
 				'page_for_privacy_policy',
 				__( 'The currently selected privacy policy page does not exist. Please create or select new page.' ),
-				'warning'
+				'error'
 			);
 		} else {
 			if ( 'trash' === $privacy_policy_page->post_status ) {
@@ -110,68 +110,62 @@
 	<h1><?php echo esc_html( $title ); ?></h1>
 	<?php settings_errors(); ?>
 
-	<h2 class="title"><?php _e( 'Privacy policy page' ); ?></h2>
-	<table class="form-table">
-		<?php
+	<h2><?php _e( 'Privacy policy page' ); ?></h2>
 
-		if ( $privacy_policy_page_exists ) {
-			$edit_href = add_query_arg(
-				array(
-					'post'  => $privacy_policy_page_id,
-					'action' => 'edit',
-				),
-				admin_url( 'post.php' )
-			);
-			$view_href = get_permalink( $privacy_policy_page_id );
+	<?php
+	if ( $privacy_policy_page_exists ) {
+		$edit_href = add_query_arg(
+			array(
+				'post'  => $privacy_policy_page_id,
+				'action' => 'edit',
+			),
+			admin_url( 'post.php' )
+		);
+		$view_href = get_permalink( $privacy_policy_page_id );
 
-			?>
-			<tr>
-				<th colspan="2">
-					<?php
-					printf(
-						__( '<a href="%1$s">Edit</a> or <a href="%2$s">view</a> your privacy policy.' ),
-						$edit_href,
-						$view_href
-					);
-					?>
-				</th>
-			</tr>
-			<?php
-		}
+		?>
+		<div class="notice notice-info inline">
+			<p>
+				<?php
+				printf(
+					__( '<a href="%1$s">Edit</a> or <a href="%2$s">view</a> your privacy policy.' ),
+					$edit_href,
+					$view_href
+				);
+				?>
+			</p>
+		</div>
+		<?php
+	}
+	?>
 
-		?>
+	<table class="form-table">
 		<tr>
 			<th scope="row">
 			<?php
+				$select_page_label = __( 'Select an existing privacy policy page' );
 
-			if ( $privacy_policy_page_exists ) {
-				_e( 'Select another page for your privacy policy' );
-			} else {
-				_e( 'Select an existing privacy policy page' );
-			}
-
+				if ( $privacy_policy_page_exists ) {
+					$select_page_label = __( 'Select another page for your privacy policy' );
+				}
 			?>
+				<label for="page_for_privacy_policy"><?php echo esc_html( $select_page_label ); ?></label>
 			</th>
 			<td id="front-static-pages">
 				<form method="post" action="">
 					<?php wp_nonce_field( 'set-privacy-page' ); ?>
 					<input type="hidden" name="action" value="set-privacy-page" />
-					<fieldset>
-						<legend class="screen-reader-text"><span><?php _e( 'Select your privacy policy page.' ); ?></span></legend>
-						<label for="page_for_privacy_policy">
-							<?php wp_dropdown_pages(
-								array(
-									'name'              => 'page_for_privacy_policy',
-									'show_option_none'  => __( '&mdash; Select &mdash;' ),
-									'option_none_value' => '0',
-									'selected'          => $privacy_policy_page_id,
-									'post_status'       => array( 'draft', 'publish' ),
-								)
-							);
-							?>
-						</label>
-					</fieldset>
-						<?php submit_button( __( 'Set Page' ) ); ?>
+					<?php wp_dropdown_pages(
+						array(
+							'name'              => 'page_for_privacy_policy',
+							'show_option_none'  => __( '&mdash; Select &mdash;' ),
+							'option_none_value' => '0',
+							'selected'          => $privacy_policy_page_id,
+							'post_status'       => array( 'draft', 'publish' ),
+						)
+					);
+					?>
+					<?php submit_button( __( 'Set Page' ), 'primary', 'submit', true, array( 'id' => 'set-page' ) ); ?>
 				</form>
 			</td>
 		</tr>
@@ -185,7 +179,7 @@
 					<form method="post" action="">
 						<input type="hidden" name="action" value="create-privacy-page" />
 						<?php wp_nonce_field( 'create-privacy-page' ); ?>
-						<?php submit_button( __( 'Create Page' ) ); ?>
+						<?php submit_button( __( 'Create Page' ), 'primary', 'submit', true, array( 'id' => 'create-page' ) ); ?>
 					</form>
 				</td>
 			</tr>
@@ -60,7 +60,7 @@
 }
 
-// If a privacy policy page ID is available, make sure the page actually exists. If not, display a warning
+// If a privacy policy page ID is available, make sure the page actually exists. If not, display an error.
 $privacy_policy_page_exists = false;
 $privacy_policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
